@@ -311,7 +311,7 @@ public:
 		e.g. GD::Image img(input, GD::Png_tag()); // read a png file from input
 		\param[in] in The io context from which to read the image data
 	*/
-	Image(gdIOCtx * in, Png_tag)
+	Image(gdIOCtxPtr in, Png_tag)
 		:im(0) {
 		CreateFromPng(in);
 	}
@@ -349,7 +349,7 @@ public:
 		e.g. GD::Image img(input, GD::Gif_tag()); // read a gif file from input
 		\param[in] in The io context from which to read the image data
 	*/
-	Image(gdIOCtx * in, Gif_tag)
+	Image(gdIOCtxPtr in, Gif_tag)
 		:im(0) {
 		CreateFromGif(in);
 	}
@@ -387,7 +387,7 @@ public:
 		e.g. GD::Image img(input, GD::WBMP_tag()); // read a monchrome WBMP file from input
 		\param[in] in The io context from which to read the image data
 	*/
-	Image(gdIOCtx * in, WBMP_tag)
+	Image(gdIOCtxPtr in, WBMP_tag)
 		:im(0) {
 		CreateFromWBMP(in);
 	}
@@ -425,7 +425,7 @@ public:
 		e.g. GD::Image img(input, GD::Jpeg_tag()); // read a jpeg file from input
 		\param[in] in The io context from which to read the image data
 	*/
-	Image(gdIOCtx * in, Jpeg_tag)
+	Image(gdIOCtxPtr in, Jpeg_tag)
 		:im(0) {
 		CreateFromJpeg(in);
 	}
@@ -463,7 +463,7 @@ public:
 		e.g. GD::Image img(input, GD::Gd_tag()); // read a gd file from input
 		\param[in] in The io context from which to read the image data
 	*/
-	Image(gdIOCtx * in, Gd_tag)
+	Image(gdIOCtxPtr in, Gd_tag)
 		:im(0) {
 		CreateFromGd(in);
 	}
@@ -501,7 +501,7 @@ public:
 		e.g. GD::Image img(input, GD::Gd2_tag()); // read a gd2 file from input
 		\param[in] in The io context from which to read the image data
 	*/
-	Image(gdIOCtx * in, Gd2_tag)
+	Image(gdIOCtxPtr in, Gd2_tag)
 		:im(0) {
 		CreateFromGd2(in);
 	}
@@ -605,7 +605,7 @@ public:
 		clear();
 		return ((im = gdImageCreateFromPng(in)) != 0);
 	}
-	bool CreateFromPng(gdIOCtx * in) {
+	bool CreateFromPng(gdIOCtxPtr in) {
 		clear();
 		return ((im = gdImageCreateFromPngCtx(in)) != 0);
 	}
@@ -624,7 +624,7 @@ public:
 		clear();
 		return ((im = gdImageCreateFromGif(in)) != 0);
 	}
-	bool CreateFromGif(gdIOCtx * in) {
+	bool CreateFromGif(gdIOCtxPtr in) {
 		clear();
 		return ((im = gdImageCreateFromGifCtx(in)) != 0);
 	}
@@ -642,7 +642,7 @@ public:
 		clear();
 		return ((im = gdImageCreateFromWBMP(in)) != 0);
 	}
-	bool CreateFromWBMP(gdIOCtx * in) {
+	bool CreateFromWBMP(gdIOCtxPtr in) {
 		clear();
 		return ((im = gdImageCreateFromWBMPCtx(in)) != 0);
 	}
@@ -680,7 +680,7 @@ public:
 		You can call Width() and Height() member functions of the image to determine its
 		size. The returned image is always a truecolor image.
 	*/
-	bool CreateFromJpeg(gdIOCtx * in) {
+	bool CreateFromJpeg(gdIOCtxPtr in) {
 		clear();
 		return ((im = gdImageCreateFromJpegCtx(in)) != 0);
 	}
@@ -715,7 +715,7 @@ public:
 		clear();
 		return ((im = gdImageCreateFromGd(in)) != 0);
 	}
-	bool CreateFromGd(gdIOCtx * in) {
+	bool CreateFromGd(gdIOCtxPtr in) {
 		clear();
 		return ((im = gdImageCreateFromGdCtx(in)) != 0);
 	}
@@ -733,7 +733,7 @@ public:
 		clear();
 		return ((im = gdImageCreateFromGd2(in)) != 0);
 	}
-	bool CreateFromGd2(gdIOCtx * in) {
+	bool CreateFromGd2(gdIOCtxPtr in) {
 		clear();
 		return ((im = gdImageCreateFromGd2Ctx(in)) != 0);
 	}
@@ -751,7 +751,7 @@ public:
 		clear();
 		return ((im = gdImageCreateFromGd2Part(in, srcx, srcy, w, h)) != 0);
 	}
-	bool CreateFromGd2Part(gdIOCtx * in, int srcx, int srcy, int w, int h) {
+	bool CreateFromGd2Part(gdIOCtxPtr in, int srcx, int srcy, int w, int h) {
 		clear();
 		return ((im = gdImageCreateFromGd2PartCtx(in, srcx, srcy, w, h)) != 0);
 	}
@@ -767,7 +767,7 @@ public:
 	bool CreateFromGd2Part(FILE * in, const Point & src, const Size & s) {
 		return CreateFromGd2Part(in, src.X(), src.Y(), s.W(), s.H());
 	}
-	bool CreateFromGd2Part(gdIOCtx * in, const Point & src, const Size & s) {
+	bool CreateFromGd2Part(gdIOCtxPtr in, const Point & src, const Size & s) {
 		return CreateFromGd2Part(in, src.X(), src.Y(), s.W(), s.H());
 	}
 	bool CreateFromGd2Part(int size, void * data, const Point & src, const Size & s) {
@@ -1055,9 +1055,9 @@ public:
 	}
 	/**
 		Write out this image in GIF file format to \p out.
-		\param out A gdIOCtx * handle
+		\param out A gdIOCtxPtr handle
 	*/
-	void Gif(gdIOCtx * out) const {
+	void Gif(gdIOCtxPtr out) const {
 		gdImageGifCtx(im, out);
 	}
 	/**
@@ -1086,9 +1086,9 @@ public:
 	}
 	/**
 		Write out this image in PNG file format to \p out.
-		\param out A gdIOCtx * handle
+		\param out A gdIOCtxPtr handle
 	*/
-	void Png(gdIOCtx * out) const {
+	void Png(gdIOCtxPtr out) const {
 		gdImagePngCtx(im, out);
 	}
 	/**
@@ -1117,10 +1117,10 @@ public:
 	}
 	/**
 		Write out this image in PNG file format to \p out.
-		\param out A gdIOCtx * handle
+		\param out A gdIOCtxPtr handle
 		\param level The level of compression: 0 == "no compression", 1 == "compressed as quickly as possible" --> 9 == "compressed as much as possible", -1 == zlib default compression level
 	*/
-	void Png(gdIOCtx * out, int level) const {
+	void Png(gdIOCtxPtr out, int level) const {
 		gdImagePngCtxEx(im, out, level);
 	}
 	/**
@@ -1153,9 +1153,9 @@ public:
 	/**
 		Write out this image in WBMP file format ( black and white only ) to \p out.
 		\param fg The color index of the foreground. All other pixels considered background.
-		\param out A gdIOCtx * handle
+		\param out A gdIOCtxPtr handle
 	*/
-	void WBMP(int fg, gdIOCtx * out) const {
+	void WBMP(int fg, gdIOCtxPtr out) const {
 		gdImageWBMPCtx(im, fg, out);
 	}
 	/**
@@ -1187,10 +1187,10 @@ public:
 	}
 	/**
 		Write out this image in JPEG file format to \p out.
-		\param out A gdIOCtx * handle
+		\param out A gdIOCtxPtr handle
 		\param quality Should be a value in the range 0-95, higher numbers imply both higher quality and larger image size.  Default value is -1, indicating "use a sensible default value".
 	*/
-	void Jpeg(gdIOCtx * out, int quality = -1) const {
+	void Jpeg(gdIOCtxPtr out, int quality = -1) const {
 		gdImageJpegCtx(im, out, quality);
 	}
 	/**
@@ -1224,16 +1224,16 @@ public:
 	inline static void GifAnimEnd(FILE * out) {
 		gdImageGifAnimEnd(out);
 	}
-	void GifAnimBegin(gdIOCtx * out, int GlobalCM, int Loops) const {
+	void GifAnimBegin(gdIOCtxPtr out, int GlobalCM, int Loops) const {
 		gdImageGifAnimBeginCtx(im, out, GlobalCM, Loops);
 	}
-	void GifAnimAdd(gdIOCtx * out, int LocalCM, int LeftOfs, int TopOfs, int Delay, int Disposal, gdImagePtr previm) const {
+	void GifAnimAdd(gdIOCtxPtr out, int LocalCM, int LeftOfs, int TopOfs, int Delay, int Disposal, gdImagePtr previm) const {
 		gdImageGifAnimAddCtx(im, out, LocalCM, LeftOfs, TopOfs, Delay, Disposal, previm);
 	}
-	void GifAnimAdd(gdIOCtx * out, int LocalCM, int LeftOfs, int TopOfs, int Delay, int Disposal, const GD::Image & previm) const {
+	void GifAnimAdd(gdIOCtxPtr out, int LocalCM, int LeftOfs, int TopOfs, int Delay, int Disposal, const GD::Image & previm) const {
 		GifAnimAdd(out, LocalCM, LeftOfs, TopOfs, Delay, Disposal, previm.im);
 	}
-	inline static void GifAnimEnd(gdIOCtx * out) {
+	inline static void GifAnimEnd(gdIOCtxPtr out) {
 		gdImageGifAnimEndCtx(out);
 	}
 	void * GifAnimBegin(int * size, int GlobalCM, int Loops) const {
